/*****< HAL.h >****************************************************************/
/*      Copyright 2010 - 2014 Stonestreet One.                                */
/*      All Rights Reserved.                                                  */
/*                                                                            */
/*  HAL - Hardware Abstraction functions for Stellaris LM3S9B96 Board         */
/*                                                                            */
/*  Author:  Tim Thomas                                                       */
/*                                                                            */
/*** MODIFICATION HISTORY *****************************************************/
/*                                                                            */
/*   mm/dd/yy  F. Lastname    Description of Modification                     */
/*   --------  -----------    ------------------------------------------------*/
/*   07/05/11  Tim Thomas     Initial creation.                               */
/******************************************************************************/
#ifndef __HAL_H__
#define __HAL_H__
#include <msp430.h>
#include "stdint.h"

   /* The following define the valid Peripheral values that may be      */
   /* passed into HAL_EnableSMCLK() and HAL_DisableSMCLK().             */
#define HAL_PERIPHERAL_DEBUG_UART                        0x01
#define HAL_PERIPHERAL_BLUETOOTH_UART                    0x02

#define IND_TX_CLK_90           BIT0    /* shifted Inductive TX carrier clock output */
#define IND_TX_CLK_0            BIT1    /* Unshifted Inductive TX carrier clock output */
#define ACLK_OUT                BIT2    /* ACLK Output for test as an output */
#define ADC_BATTERY_MONITOR     BIT3    /* ADC CH3 for Battery voltage monitor input */
#define MCLK_OUT                BIT4    /* MCLK Output for test */
#define ADC_PEAK_DETECT         BIT5    /* Inductive Receiver Peak Signal (Auto gain) */
#define MCU_P1_6_BIT            BIT6    /* Not used */
#define PUSH_BUTTON_ADV         BIT7    /* Push button to start BT advertising as input */

#define P1DIR_INIT      (IND_TX_CLK_90 | IND_TX_CLK_0 | ACLK_OUT | MCLK_OUT | MCU_P1_6_BIT)
#define P1OUT_INIT      (0)
#define P1SEL0_INIT     (ACLK_OUT | ADC_BATTERY_MONITOR | MCLK_OUT | ADC_PEAK_DETECT)
#define P1SEL1_INIT     (ADC_BATTERY_MONITOR | ADC_PEAK_DETECT)


#define MCU_P2_0_BIT            BIT0    /* Not used */
#define BT_SHUTDOWN_PIN         BIT1    /* Bluetooth Reset to the cc2564 Shutdown as output */
#define BT_UART_RTS             BIT2    /* Ready-to-Send (RTS) to the cc2654 as output*/
#define BT_UART_CTS             BIT3    /* Clear-to-Send (CTS) to the cc2654 as input */
#define MCU_P2_4_BIT            BIT4    /* Not used */
#define USB_SUSPEND_WAKEUP      BIT5    /* USB-Bridge input isr from suspend line */
#define MCU_P2_6_BIT            BIT6    /* Not used */
#define MCU_P2_7_BIT            BIT7    /* Not used */

#define P2DIR_INIT      ( MCU_P2_0_BIT | BT_SHUTDOWN_PIN | BT_UART_RTS | \
MCU_P2_4_BIT | MCU_P2_6_BIT | MCU_P2_7_BIT )
#define P2OUT_INIT      (0)
#define P2SEL0_INIT     (0)

#define WIRED_UART_RX           BIT0    /* UART Receive line for Wired connection with Programmer */
#define WIRED_UART_TX           BIT1    /* UART Transmit line for Wired connection with Programmer */
#define MCU_P3_2_BIT            BIT2    /* Not used */
#define MCU_P3_3_BIT            BIT3    /* Not used */
#define BT_UART_RX              BIT4    /* UART Receive line for BT Serial Port Profile connection with Programmer */
#define BT_UART_TX              BIT5    /* UART Transmit line for BT Serial Port Profile connection with Programmer */
#define IND_UART_RX             BIT6    /* UART Receive line for Inductive communication */
#define IND_UART_TX             BIT7    /* UART Transmit line for Inductive communication */

#define P3DIR_INIT        ( WIRED_UART_TX | MCU_P3_2_BIT | MCU_P3_3_BIT | BT_UART_TX | \
IND_UART_TX )

#define P3OUT_INIT        (0)
#define P3SEL0_INIT       (WIRED_UART_RX | WIRED_UART_TX | BT_UART_RX | BT_UART_TX | IND_UART_RX |IND_UART_TX)

#define IND_RX_PEAK_DET_DIS     BIT0    /* Inductive RX peak detect line discharge */
#define DBG_UART_RX             BIT1    /* UART Receive line for Debug monitor */
#define DBG_UART_TX             BIT2    /* UART Transmit line for Debug monitor */
#define IND_X_COIL_EN           BIT3    /* Inductive interface x coil enable output */
#define IND_Y_COIL_EN           BIT4    /* Inductive interface y coil enable output */
#define IND_Z_COIL_EN           BIT5    /* Inductive interface z coil enable output */
#define IND_RX_AMP_EN           BIT6    /* Inductive interface recv amplifier enable */
#define MCU_P4_7_BIT            BIT7    /* High baud-rate RX damping enable/disable */

#define P4DIR_INIT      ( IND_RX_PEAK_DET_DIS | DBG_UART_TX | IND_X_COIL_EN | \
IND_Y_COIL_EN | IND_Z_COIL_EN | IND_RX_AMP_EN | MCU_P4_7_BIT)
#define P4OUT_INIT      (DBG_UART_RX | DBG_UART_TX)
#define P4SEL0_INIT     (DBG_UART_RX | DBG_UART_TX)


#define HI_BAUD_RX_DAMP_EN      BIT0    /* High baud rate RX damping Enable/Disable */
#define EN_POW_MCU              BIT1    /* Power Enable to MCU */
#define EN_POW_RX               BIT2    /* Power Enable to inductive RX */
#define EN_POW_TX               BIT3    /* Power Enable to inductive TX */
#define TP_1                    BIT4    /* Test point 1 for debug */
#define TP_2                    BIT5    /* Test point 2 for debug */
#define TP_3                    BIT6    /* Test point 3 for debug */
#define TP_4                    BIT7    /* Test point 4 for debug */

#define P5DIR_INIT      ( HI_BAUD_RX_DAMP_EN | EN_POW_MCU | EN_POW_RX | EN_POW_TX | \
TP_1 | TP_2 | TP_3 | TP_4 )
#define P5OUT_INIT      (EN_POW_MCU)

#define set_tp1      P5OUT |=  TP_1
#define clr_tp1      P5OUT &= ~TP_1
#define toggle_tp1   P5OUT ^= TP_1

#define set_tp2      P5OUT |=  TP_2
#define clr_tp2      P5OUT &= ~TP_2
#define toggle_tp2   P5OUT ^= TP_2

#define set_tp3      P5OUT |=  TP_3
#define clr_tp3      P5OUT &= ~TP_3
#define toggle_tp3   P5OUT ^= TP_3

#define set_tp4      P5OUT |=  TP_4
#define clr_tp4      P5OUT &= ~TP_4
#define toggle_tp4   P5OUT ^= TP_4


#define LED_WHITE               BIT0    /* Status LED */  // LED_BLUE
#define LED_GREEN_B_R           BIT1    /* Status LED */  // LED_GREEN_bottom_right
#define LED_GREEN_T_R           BIT2    /* Status LED */  // LED_GREEN_top_right
#define LED_GREEN_T_L           BIT3    /* Status LED */  // LED_GREEN_top_left
#define LED_GREEN_B_L           BIT4    /* Status LED */  // LED_GREEN_bottom_left
#define LED_GREEN				(LED_GREEN_T_L | LED_GREEN_T_R | LED_GREEN_B_R | LED_GREEN_B_L)
#define LED_GREEN_BOTTOM		(LED_GREEN_B_R | LED_GREEN_B_L)
#define LED_ORANGE              BIT5    /* Status LED */  // LED_ORANGE
#define MCU_P6_6_BIT            BIT6    /* Not used */
#define MCU_P6_7_BIT            BIT7    /* Not used */

#define P6DIR_INIT      ( LED_WHITE | LED_GREEN_B_R | LED_GREEN_T_R | LED_GREEN_T_L | \
LED_GREEN_B_L | LED_ORANGE | MCU_P6_6_BIT | MCU_P6_7_BIT )
#define P6OUT_INIT      (0)



#define MCU_P7_0_BIT            BIT0    /* Not used */
#define MCU_P7_1_BIT            BIT1    /* Not used */
#define MCU_P7_2_BIT            BIT2    /* Not used */
#define MCU_P7_3_BIT            BIT3    /* Not used */
#define MCU_P7_4_BIT            BIT4    /* Not used */
#define MCU_P7_5_BIT            BIT5    /* Not used */
#define MCU_P7_6_BIT            BIT6    /* Not used */
#define MCU_P7_7_BIT            BIT7    /* Not used */

#define P7DIR_INIT      ( MCU_P7_0_BIT | MCU_P7_1_BIT | MCU_P7_2_BIT | MCU_P7_3_BIT | \
MCU_P7_4_BIT | MCU_P7_5_BIT | MCU_P7_6_BIT | MCU_P7_7_BIT )
#define P7OUT_INIT      (0)

#define MCU_P8_0_BIT            BIT0    /* Not used */
#define MCU_P8_1_BIT            BIT1    /* Not used */

#define P8DIR_INIT      ( MCU_P8_0_BIT | MCU_P8_1_BIT )
#define P8OUT_INIT      (0)

#define MCU_PJ_0_BIT            BIT0    /* Not used */
#define MCU_PJ_1_BIT            BIT1    /* Not used */
#define MCU_PJ_2_BIT            BIT2    /* Not used */
#define MCU_PJ_3_BIT            BIT3    /* Not used */

#define PJDIR_INIT      ( MCU_PJ_0_BIT | MCU_PJ_1_BIT | MCU_PJ_2_BIT | MCU_PJ_3_BIT )
#define PJOUT_INIT      (0)

#define BSP_SYS_TIMER0_IV_OFFSET         (BSP_TIMER0_A0_VECTOR)
#define BSP_SYS_TIMER1_IV_OFFSET         (BSP_TIMER0_A1_VECTOR)
#define BSP_SYS_TIMER_BASE_ADDR          (TA0CTL)
#define BSP_SYS_TIMER_CTL                (TA0CTL)
#define BSP_SYS_TIMER_CCTL0              (TA0CCTL0)
#define BSP_SYS_TIMER_CCTL1              (TA0CCTL1)
#define BSP_SYS_TIMER_CCTL2              (TA0CCTL2)
#define BSP_SYS_TIMER_COUNTER            (TA0R)
#define BSP_SYS_TIMER_CCR0               (TA0CCR0)
#define BSP_SYS_TIMER_CCR1               (TA0CCR1)
#define BSP_SYS_TIMER_EX0                (TA0EX0)
#define BSP_SYS_TIMER_IV                 (TA0IV)

#define BSP_SYS_TIMER_IFG                 (TA0IV_TAIFG)

#define NO_PARITY    0
#define LSB_FIRST    0
#define DATA_8BIT    0
#define ONE_STOP_BIT 0
#define UART_MODE    0
#define ASYNC_MODE   0

#define P1_IVR                               (P1IV)
#define P2_IVR                               (P2IV)

#define PUSH_BUTTON_IN                       (P1IN)
#define PUSH_BUTTON_OUT                      (P1OUT)
#define PUSH_BUTTON_DIR                      (P1DIR)
#define PUSH_BUTTON_REN                      (P1REN)
#define PUSH_BUTTON_DS                       (P1DS)
#define PUSH_BUTTON_SEL                      (P1SEL0)
#define PUSH_BUTTON_IES                      (P1IES)
#define PUSH_BUTTON_IE                       (P1IE)
#define PUSH_BUTTON_IFG                      (P1IFG)

#define PUSH_BUTTON_IVR                      (P1IV)
#define PUSH_BUTTON_INT_NUM                  (P1IV_P1IFG7)

#define USB_SUSPEND_IVR                      (P2IV)
#define USB_SUSPEND_INT_NUM                  (P2IV_P2IFG5)

#define BT_SLOW_CLK_BASE_ADDR                (P1IN)
#define BT_SLOW_CLK_IN                       (P1IN)
#define BT_SLOW_CLK_OUT                      (P1OUT)
#define BT_SLOW_CLK_DIR                      (P1DIR)
#define BT_SLOW_CLK_SEL                      (P1SEL0)

#define BT_UART_FLOW_BASE_ADDR               (P2IN)
#define BT_UART_FLOW_IN                      (P2IN)
#define BT_UART_FLOW_OUT                     (P2OUT)
#define BT_UART_FLOW_DIR                     (P2DIR)
#define BT_UART_FLOW_REN                     (P2REN)
#define BT_UART_FLOW_DS                      (P2DS)
#define BT_UART_FLOW_SEL                     (P2SEL0)
#define BT_UART_FLOW_IES                     (P2IES)
#define BT_UART_FLOW_IE                      (P2IE)
#define BT_UART_FLOW_IFG                     (P2IFG)

#define BT_CTS_IVR                           (P2IV)
#define BT_CTS_INT_NUM                       (P2IV_P2IFG3)

#define BT_DEV_SHUTDOWN_BASE_ADDR            (P2IN)
#define BT_DEV_SHUTDOWN_IN                   (P2IN)
#define BT_DEV_SHUTDOWN_OUT                  (P2OUT)
#define BT_DEV_SHUTDOWN_DIR                  (P2DIR)
#define BT_DEV_SHUTDOWN_SEL                  (P2SEL0)

#define BT_UART_BASE_ADDR                    (UCA1CTLW0)
#define BT_UART_CONTROL1                     (UCA1CTL1)
#define BT_UART_CONTROL0                     (UCA1CTL0)
#define BT_UART_BAUD_RATE_CONTROL            (UCA1BRW)
#define BT_UART_MODULATION_CONTROL           (UCA1MCTLW)
#define BT_UART_RXBUF                        (UCA1RXBUF)
#define BT_UART_TXBUF                        (UCA1TXBUF)
#define BT_UART_INT_ENABLE                   (UCA1IE)
#define BT_UART_INT_FLAG                     (UCA1IFG)
#define BT_UART_INT_VECTOR                   (UCA1IV)

#define BT_UART_PORT_BASE_ADDR               (P3IN)
#define BT_UART_PORT_IN                      (P3IN)
#define BT_UART_PORT_OUT                     (P3OUT)
#define BT_UART_PORT_DIR                     (P3DIR)
#define BT_UART_PORT_SEL                     (P3SEL0)

#define BT_FLOW_OFF()   BT_UART_FLOW_OUT |= BT_UART_RTS;

#define BT_FLOW_ON()    BT_UART_FLOW_OUT &= ~(BT_UART_RTS);

#define BT_CONFIG_SLOW_CLK()     BT_SLOW_CLK_DIR |= ACLK_OUT; \
                                 BT_SLOW_CLK_SEL |= ACLK_OUT; \

#define BT_CONFIG_IO()           BT_UART_PORT_SEL |= (BT_UART_TX | BT_UART_RX); \
                                 BT_UART_PORT_DIR |= (BT_UART_TX); \
                                 BT_UART_PORT_DIR &= ~(BT_UART_RX); \

#define BT_CONFIG_RTS()          BT_UART_FLOW_OUT &= ~(BT_UART_RTS); \
                                 BT_UART_FLOW_DIR |= (BT_UART_RTS); \
                                 BT_UART_FLOW_SEL &= ~(BT_UART_RTS); \
                                 BT_UART_FLOW_DS  |= (BT_UART_RTS); \
                                 BT_UART_FLOW_IFG &= ~(BT_UART_RTS); \

#define BT_CONFIG_CTS()          BT_UART_FLOW_OUT &= ~(BT_UART_CTS); \
                                 BT_UART_FLOW_DIR &= ~(BT_UART_CTS); \
                                 BT_UART_FLOW_SEL &= ~(BT_UART_CTS); \
                                 BT_UART_FLOW_IES |= (BT_UART_CTS); \
                                 BT_UART_FLOW_IE  |= (BT_UART_CTS); \
                                 BT_UART_FLOW_IFG &= ~(BT_UART_CTS); \

#define BT_RESET_HOLD()       BT_DEV_SHUTDOWN_OUT &= ~(BT_SHUTDOWN_PIN);
#define BT_RESET_RELEASE()    BT_DEV_SHUTDOWN_OUT |= (BT_SHUTDOWN_PIN);

#define WIRED_UART_IV_OFFSET                 (BSP_USCI_A0_VECTOR)
#define WIRED_UART_CTLW0                     (UCA0CTLW0)
#define WIRED_UART_CONTROL1                  (UCA0CTL1)
#define WIRED_UART_CONTROL0                  (UCA0CTL0)
#define WIRED_UART_BRW                       (UCA0BRW)
#define WIRED_UART_MCTLW                     (UCA0MCTLW)
#define WIRED_UART_RXBUF                     (UCA0RXBUF)
#define WIRED_UART_TXBUF                     (UCA0TXBUF)
#define WIRED_UART_IE                        (UCA0IE)
#define WIRED_UART_IFG                       (UCA0IFG)
#define WIRED_UART_IV                        (UCA0IV)

#define WIRED_UART_PORT_IN                   (P3IN)
#define WIRED_UART_PORT_OUT                  (P3OUT)
#define WIRED_UART_PORT_DIR                  (P3DIR)
#define WIRED_UART_PORT_SEL                  (P3SEL0)

#define WIRED_TIMER0_IV_OFFSET         (BSP_TIMER3_A0_VECTOR)
#define WIRED_TIMER1_IV_OFFSET         (BSP_TIMER3_A1_VECTOR)
#define WIRED_TIMER_BASE_ADDR          (TA3CTL)
#define WIRED_TIMER_CTL                (TA3CTL)
#define WIRED_TIMER_CCTL0              (TA3CCTL0)
#define WIRED_TIMER_CCTL1              (TA3CCTL1)
#define WIRED_TIMER_COUNTER            (TA3R)
#define WIRED_TIMER_CCR0               (TA3CCR0)
#define WIRED_TIMER_CCR1               (TA3CCR1)
#define WIRED_TIMER_EX0                (TA3EX0)
#define WIRED_TIMER_IV                 (TA3IV)

#define INDCOMM_UART_IV_OFFSET              (BSP_USCI_A2_VECTOR)
#define INDCOMM_UART_CTLW0                  (UCA2CTLW0)
#define INDCOMM_UART_BRW                    (UCA2BRW)
#define INDCOMM_UART_MCTLW                  (UCA2MCTLW)
#define INDCOMM_UART_RXBUF                  (UCA2RXBUF)
#define INDCOMM_UART_TXBUF                  (UCA2TXBUF)
#define INDCOMM_UART_IE                     (UCA2IE)
#define INDCOMM_UART_IFG                    (UCA2IFG)
#define INDCOMM_UART_IV                     (UCA2IV)

#define INDCOMM_UART_PORT_IN                (P3IN)
#define INDCOMM_UART_PORT_OUT               (P3OUT)
#define INDCOMM_UART_PORT_DIR               (P3DIR)
#define INDCOMM_UART_PORT_SEL               (P3SEL0)
#define INDCOMM_UART_PORT_REN               (P3REN)

#define INDCOMM_COILSEL_PORT_IN               (P4IN)
#define INDCOMM_COILSEL_PORT_OUT              (P4OUT)
#define INDCOMM_COILSEL_PORT_DIR              (P4DIR)
#define INDCOMM_COILSEL_PORT_SEL              (P4SEL0)


#define INDCOMM_LED_ON()                    (P6OUT |=  LED_WHITE)
#define INDCOMM_LED_OFF()                   (P6OUT &= ~LED_WHITE)

#define INDCOMM_POW_TX_ON()                 (P5OUT |=  EN_POW_TX)
#define INDCOMM_POW_TX_OFF()                (P5OUT &= ~EN_POW_TX)

#define INDCOMM_POW_RX_ON()                 (P5OUT |=  EN_POW_RX)
#define INDCOMM_POW_RX_OFF()                (P5OUT &= ~EN_POW_RX)

#define INDCOMM_DAMP_RES_EN()                 (P5OUT |=  HI_BAUD_RX_DAMP_EN)
#define INDCOMM_DAMP_RES_DIS()                (P5OUT &= ~HI_BAUD_RX_DAMP_EN)

#define INDCOMM_RX_AMP_EN()                 (P4OUT |=  IND_RX_AMP_EN)
#define INDCOMM_RX_AMP_DIS()                (P4OUT &= ~IND_RX_AMP_EN)

#define INDCOMM_IND_RX_PEAK_DET_DISCHARGE() (P4OUT |= IND_RX_PEAK_DET_DIS)
#define INDCOMM_IND_RX_PEAK_DET_EN()        (P4OUT &= ~IND_RX_PEAK_DET_DIS)

/* Inductive Transmit Clock output (90 deg phase shift) P1.0/PM_TA1.1/VeREF-/A0*/
#define INDCOMM_TIMER_TXCLK90_PSEL      (P1SEL0)
#define INDCOMM_TIMER_TXCLK90_PDIR      (P1DIR)
#define INDCOMM_TIMER_TXCLK90_PIN       (P1IN)
#define INDCOMM_TIMER_TXCLK90_POUT      (P1OUT)
/**/
#define INDCOMM_TXCLK90_TIMER0_IV_OFFSET          (BSP_TIMER1_A0_VECTOR)
#define INDCOMM_TXCLK90_TIMER1_IV_OFFSET          (BSP_TIMER1_A1_VECTOR)
#define INDCOMM_TXCLK90_TIMER_BASE_ADDR          (TA1CTL)
#define INDCOMM_TXCLK90_TIMER_CTL                (TA1CTL)
#define INDCOMM_TXCLK90_TIMER_CCTL0              (TA1CCTL0)
#define INDCOMM_TXCLK90_TIMER_CCTL1              (TA1CCTL1)
#define INDCOMM_TXCLK90_TIMER_COUNTER            (TA1R)
#define INDCOMM_TXCLK90_TIMER_CCR0               (TA1CCR0)
#define INDCOMM_TXCLK90_TIMER_CCR1               (TA1CCR1)
#define INDCOMM_TXCLK90_TIMER_EX0                (TA1EX0)
#define INDCOMM_TXCLK90_TIMER_IV                 (TA1IV)


/* Inductive Transmit Clock output (0 deg phase shift) P1.1/TA2.1/CBOUT/VeREF+/A1*/
#define INDCOMM_TIMER_TXCLK_PSEL      (P1SEL0)
#define INDCOMM_TIMER_TXCLK_PDIR      (P1DIR)
#define INDCOMM_TIMER_TXCLK_PIN       (P1IN)
#define INDCOMM_TIMER_TXCLK_POUT      (P1OUT)
/* Inductive Comm Timer - used for generating TXCLK and used for UART RX (timeout)*/
#define INDCOMM_TIMER0_IV_OFFSET          (BSP_TIMER2_A0_VECTOR)
#define INDCOMM_TIMER1_IV_OFFSET          (BSP_TIMER2_A1_VECTOR)
#define INDCOMM_TIMER_BASE_ADDR          (TA2CTL)
#define INDCOMM_TIMER_CTL                (TA2CTL)
#define INDCOMM_TIMER_CCTL0              (TA2CCTL0)
#define INDCOMM_TIMER_CCTL1              (TA2CCTL1)
#define INDCOMM_TIMER_COUNTER            (TA2R)
#define INDCOMM_TIMER_CCR0               (TA2CCR0)
#define INDCOMM_TIMER_CCR1               (TA2CCR1)
#define INDCOMM_TIMER_EX0                (TA2EX0)
#define INDCOMM_TIMER_IV                 (TA2IV)

#define DBG_UART_IV_OFFSET              (BSP_USCI_A3_VECTOR)
#define DBG_UART_CTLW0                  (UCA3CTLW0)
#define DBG_UART_BRW                    (UCA3BRW)
#define DBG_UART_MCTLW                  (UCA3MCTLW)
#define DBG_UART_RXBUF                  (UCA3RXBUF)
#define DBG_UART_TXBUF                  (UCA3TXBUF)
#define DBG_UART_IE                     (UCA3IE)
#define DBG_UART_IFG                    (UCA3IFG)
#define DBG_UART_IV                     (UCA3IV)

#define DBG_UART_PORT_IN                (P4IN)
#define DBG_UART_PORT_OUT               (P4OUT)
#define DBG_UART_PORT_DIR               (P4DIR)
#define DBG_UART_PORT_SEL               (P4SEL0)

#define DEV_BATT_MON_CH         (ADC10INCH_3)


   /* The following function is used to place the hardware into a known */
   /* state.                                                            */
void HAL_ConfigureHardware(void);

   /* * NOTE * The following are the allowed flags for the flags        */
   /*          argument.                                                */
   /*  1.  UART_CONFIG_WLEN_8, UART_CONFIG_WLEN_7                       */
   /*  2.  UART_CONFIG_PAR_NONE,UART_CONFIG_PAR_ODD,UART_CONFIG_PAR_EVEN*/
   /*  3.  UART_CONFIG_STOP_ONE,UART_CONFIG_STOP_TWO                    */
   /*          The flags is a bitfield which may include one flag from  */
   /*          each of the three rows above                             */
void HAL_CommConfigure(unsigned char *UartBase, unsigned long BaudRate, unsigned char Flags);

   /* The following function is used to retreive data from the UART     */
   /* input queue.  The function receives a pointer to a buffer that    */
   /* will receive the UART characters a the length of the buffer.  The */
   /* function will return the number of characters that were returned  */
   /* in Buffer.                                                        */
int HAL_ConsoleRead(unsigned int Length, char *Buffer);

   /* The following function is used to send data to the UART output    */
   /* queue.  The function receives a pointer to a buffer that will     */
   /* contains the data to send and the length of the data.             */
void HAL_ConsoleWrite(unsigned int Length, char *Buffer);

   /* The following function is used to return the configured system    */
   /* clock speed in MHz.                                               */
unsigned long HAL_GetSystemSpeed(void);

   /* This function is called to get the system Tick Count.             */
unsigned long HAL_GetTickCount(void);

   /* The following function is used to toggle the state of an LED.  The*/
   /* number of LEDs on a board is board specific.  If the LED_ID       */
   /* provided does not exist on the hardware platform then nothing is  */
   /* done.                                                             */
void HAL_LedToggle(int LED_ID);

   /* The following function is used to set an LED to a specified state.*/
void HAL_SetLED(int LED_ID, int State);

   /* The following function is called to enable the SMCLK Peripheral   */
   /* on the MSP430.                                                    */
   /* * NOTE * This function should be called with interrupts disabled. */
void HAL_EnableSMCLK(unsigned char Peripheral);

   /* The following function is called to disable the SMCLK Peripheral  */
   /* on the MSP430.                                                    */
   /* * NOTE * This function should be called with interrupts disabled. */
void HAL_DisableSMCLK(unsigned char Peripheral);

   /* The following function is called to enter LPM3 mode on the MSP    */
   /* with the OS Timer Tick Disabled.                                  */
void HAL_LowPowerMode(unsigned char DisableLED);

#endif

